# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v4alpha/extension.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import config_source_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/core/v4alpha/extension.proto',
  package='envoy.config.core.v4alpha',
  syntax='proto3',
  serialized_options=b'\n\'io.envoyproxy.envoy.config.core.v4alphaB\016ExtensionProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)envoy/config/core/v4alpha/extension.proto\x12\x19\x65nvoy.config.core.v4alpha\x1a-envoy/config/core/v4alpha/config_source.proto\x1a\x19google/protobuf/any.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x95\x01\n\x14TypedExtensionConfig\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x34\n\x0ctyped_config\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x08\xfa\x42\x05\xa2\x01\x02\x08\x01:0\x9a\xc5\x88\x1e+\n)envoy.config.core.v3.TypedExtensionConfig\"\x8d\x02\n\x15\x45xtensionConfigSource\x12H\n\rconfig_source\x18\x01 \x01(\x0b\x32\'.envoy.config.core.v4alpha.ConfigSourceB\x08\xfa\x42\x05\xa2\x01\x02\x08\x01\x12,\n\x0e\x64\x65\x66\x61ult_config\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12,\n$apply_default_config_without_warming\x18\x03 \x01(\x08\x12\x1b\n\ttype_urls\x18\x04 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01:1\x9a\xc5\x88\x1e,\n*envoy.config.core.v3.ExtensionConfigSourceBC\n\'io.envoyproxy.envoy.config.core.v4alphaB\x0e\x45xtensionProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_TYPEDEXTENSIONCONFIG = _descriptor.Descriptor(
  name='TypedExtensionConfig',
  full_name='envoy.config.core.v4alpha.TypedExtensionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.core.v4alpha.TypedExtensionConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.core.v4alpha.TypedExtensionConfig.typed_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\242\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.config.core.v3.TypedExtensionConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=387,
)


_EXTENSIONCONFIGSOURCE = _descriptor.Descriptor(
  name='ExtensionConfigSource',
  full_name='envoy.config.core.v4alpha.ExtensionConfigSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_source', full_name='envoy.config.core.v4alpha.ExtensionConfigSource.config_source', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\242\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='envoy.config.core.v4alpha.ExtensionConfigSource.default_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='apply_default_config_without_warming', full_name='envoy.config.core.v4alpha.ExtensionConfigSource.apply_default_config_without_warming', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_urls', full_name='envoy.config.core.v4alpha.ExtensionConfigSource.type_urls', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036,\n*envoy.config.core.v3.ExtensionConfigSource',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=390,
  serialized_end=659,
)

_TYPEDEXTENSIONCONFIG.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_EXTENSIONCONFIGSOURCE.fields_by_name['config_source'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2._CONFIGSOURCE
_EXTENSIONCONFIGSOURCE.fields_by_name['default_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['TypedExtensionConfig'] = _TYPEDEXTENSIONCONFIG
DESCRIPTOR.message_types_by_name['ExtensionConfigSource'] = _EXTENSIONCONFIGSOURCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TypedExtensionConfig = _reflection.GeneratedProtocolMessageType('TypedExtensionConfig', (_message.Message,), {
  'DESCRIPTOR' : _TYPEDEXTENSIONCONFIG,
  '__module__' : 'envoy.config.core.v4alpha.extension_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v4alpha.TypedExtensionConfig)
  })
_sym_db.RegisterMessage(TypedExtensionConfig)

ExtensionConfigSource = _reflection.GeneratedProtocolMessageType('ExtensionConfigSource', (_message.Message,), {
  'DESCRIPTOR' : _EXTENSIONCONFIGSOURCE,
  '__module__' : 'envoy.config.core.v4alpha.extension_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v4alpha.ExtensionConfigSource)
  })
_sym_db.RegisterMessage(ExtensionConfigSource)


DESCRIPTOR._options = None
_TYPEDEXTENSIONCONFIG.fields_by_name['name']._options = None
_TYPEDEXTENSIONCONFIG.fields_by_name['typed_config']._options = None
_TYPEDEXTENSIONCONFIG._options = None
_EXTENSIONCONFIGSOURCE.fields_by_name['config_source']._options = None
_EXTENSIONCONFIGSOURCE.fields_by_name['type_urls']._options = None
_EXTENSIONCONFIGSOURCE._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/v3/hash_policy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/type/v3/hash_policy.proto',
  package='envoy.type.v3',
  syntax='proto3',
  serialized_options=b'\n\033io.envoyproxy.envoy.type.v3B\017HashPolicyProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x65nvoy/type/v3/hash_policy.proto\x12\renvoy.type.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xaf\x01\n\nHashPolicy\x12\x37\n\tsource_ip\x18\x01 \x01(\x0b\x32\".envoy.type.v3.HashPolicy.SourceIpH\x00\x1a\x31\n\x08SourceIp:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.type.HashPolicy.SourceIp:\x1c\x9a\xc5\x88\x1e\x17\n\x15\x65nvoy.type.HashPolicyB\x17\n\x10policy_specifier\x12\x03\xf8\x42\x01\x42\x38\n\x1bio.envoyproxy.envoy.type.v3B\x0fHashPolicyProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_HASHPOLICY_SOURCEIP = _descriptor.Descriptor(
  name='SourceIp',
  full_name='envoy.type.v3.HashPolicy.SourceIp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036 \n\036envoy.type.HashPolicy.SourceIp',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=262,
)

_HASHPOLICY = _descriptor.Descriptor(
  name='HashPolicy',
  full_name='envoy.type.v3.HashPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_ip', full_name='envoy.type.v3.HashPolicy.source_ip', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HASHPOLICY_SOURCEIP, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\027\n\025envoy.type.HashPolicy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='policy_specifier', full_name='envoy.type.v3.HashPolicy.policy_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=142,
  serialized_end=317,
)

_HASHPOLICY_SOURCEIP.containing_type = _HASHPOLICY
_HASHPOLICY.fields_by_name['source_ip'].message_type = _HASHPOLICY_SOURCEIP
_HASHPOLICY.oneofs_by_name['policy_specifier'].fields.append(
  _HASHPOLICY.fields_by_name['source_ip'])
_HASHPOLICY.fields_by_name['source_ip'].containing_oneof = _HASHPOLICY.oneofs_by_name['policy_specifier']
DESCRIPTOR.message_types_by_name['HashPolicy'] = _HASHPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HashPolicy = _reflection.GeneratedProtocolMessageType('HashPolicy', (_message.Message,), {

  'SourceIp' : _reflection.GeneratedProtocolMessageType('SourceIp', (_message.Message,), {
    'DESCRIPTOR' : _HASHPOLICY_SOURCEIP,
    '__module__' : 'envoy.type.v3.hash_policy_pb2'
    # @@protoc_insertion_point(class_scope:envoy.type.v3.HashPolicy.SourceIp)
    })
  ,
  'DESCRIPTOR' : _HASHPOLICY,
  '__module__' : 'envoy.type.v3.hash_policy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.v3.HashPolicy)
  })
_sym_db.RegisterMessage(HashPolicy)
_sym_db.RegisterMessage(HashPolicy.SourceIp)


DESCRIPTOR._options = None
_HASHPOLICY_SOURCEIP._options = None
_HASHPOLICY.oneofs_by_name['policy_specifier']._options = None
_HASHPOLICY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/trace/v3/http_tracer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/trace/v3/http_tracer.proto',
  package='envoy.config.trace.v3',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.config.trace.v3B\017HttpTracerProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'envoy/config/trace/v3/http_tracer.proto\x12\x15\x65nvoy.config.trace.v3\x1a\x19google/protobuf/any.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xf8\x01\n\x07Tracing\x12\x31\n\x04http\x18\x01 \x01(\x0b\x32#.envoy.config.trace.v3.Tracing.Http\x1a\x93\x01\n\x04Http\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:)\x9a\xc5\x88\x1e$\n\"envoy.config.trace.v2.Tracing.HttpB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig:$\x9a\xc5\x88\x1e\x1f\n\x1d\x65nvoy.config.trace.v2.TracingB@\n#io.envoyproxy.envoy.config.trace.v3B\x0fHttpTracerProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_TRACING_HTTP = _descriptor.Descriptor(
  name='Http',
  full_name='envoy.config.trace.v3.Tracing.Http',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.trace.v3.Tracing.Http.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.trace.v3.Tracing.Http.typed_config', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.config.trace.v2.Tracing.Http',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.config.trace.v3.Tracing.Http.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=248,
  serialized_end=395,
)

_TRACING = _descriptor.Descriptor(
  name='Tracing',
  full_name='envoy.config.trace.v3.Tracing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http', full_name='envoy.config.trace.v3.Tracing.http', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRACING_HTTP, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\037\n\035envoy.config.trace.v2.Tracing',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=433,
)

_TRACING_HTTP.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_TRACING_HTTP.containing_type = _TRACING
_TRACING_HTTP.oneofs_by_name['config_type'].fields.append(
  _TRACING_HTTP.fields_by_name['typed_config'])
_TRACING_HTTP.fields_by_name['typed_config'].containing_oneof = _TRACING_HTTP.oneofs_by_name['config_type']
_TRACING.fields_by_name['http'].message_type = _TRACING_HTTP
DESCRIPTOR.message_types_by_name['Tracing'] = _TRACING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Tracing = _reflection.GeneratedProtocolMessageType('Tracing', (_message.Message,), {

  'Http' : _reflection.GeneratedProtocolMessageType('Http', (_message.Message,), {
    'DESCRIPTOR' : _TRACING_HTTP,
    '__module__' : 'envoy.config.trace.v3.http_tracer_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.trace.v3.Tracing.Http)
    })
  ,
  'DESCRIPTOR' : _TRACING,
  '__module__' : 'envoy.config.trace.v3.http_tracer_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.trace.v3.Tracing)
  })
_sym_db.RegisterMessage(Tracing)
_sym_db.RegisterMessage(Tracing.Http)


DESCRIPTOR._options = None
_TRACING_HTTP.fields_by_name['name']._options = None
_TRACING_HTTP._options = None
_TRACING._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/health_check/v2/health_check.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.route import route_components_pb2 as envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2
from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/health_check/v2/health_check.proto',
  package='envoy.config.filter.http.health_check.v2',
  syntax='proto3',
  serialized_options=b'\n6io.envoyproxy.envoy.config.filter.http.health_check.v2B\020HealthCheckProtoP\001\362\230\376\217\005/\022-envoy.extensions.filters.http.health_check.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n;envoy/config/filter/http/health_check/v2/health_check.proto\x12(envoy.config.filter.http.health_check.v2\x1a)envoy/api/v2/route/route_components.proto\x1a\x18\x65nvoy/type/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x94\x03\n\x0bHealthCheck\x12?\n\x11pass_through_mode\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12-\n\ncache_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x80\x01\n\x1f\x63luster_min_healthy_percentages\x18\x04 \x03(\x0b\x32W.envoy.config.filter.http.health_check.v2.HealthCheck.ClusterMinHealthyPercentagesEntry\x12\x32\n\x07headers\x18\x05 \x03(\x0b\x32!.envoy.api.v2.route.HeaderMatcher\x1aX\n!ClusterMinHealthyPercentagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.envoy.type.Percent:\x02\x38\x01J\x04\x08\x02\x10\x03\x42\x89\x01\n6io.envoyproxy.envoy.config.filter.http.health_check.v2B\x10HealthCheckProtoP\x01\xf2\x98\xfe\x8f\x05/\x12-envoy.extensions.filters.http.health_check.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2.DESCRIPTOR,envoy_dot_type_dot_percent__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY = _descriptor.Descriptor(
  name='ClusterMinHealthyPercentagesEntry',
  full_name='envoy.config.filter.http.health_check.v2.HealthCheck.ClusterMinHealthyPercentagesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.filter.http.health_check.v2.HealthCheck.ClusterMinHealthyPercentagesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.filter.http.health_check.v2.HealthCheck.ClusterMinHealthyPercentagesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=637,
  serialized_end=725,
)

_HEALTHCHECK = _descriptor.Descriptor(
  name='HealthCheck',
  full_name='envoy.config.filter.http.health_check.v2.HealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pass_through_mode', full_name='envoy.config.filter.http.health_check.v2.HealthCheck.pass_through_mode', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cache_time', full_name='envoy.config.filter.http.health_check.v2.HealthCheck.cache_time', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_min_healthy_percentages', full_name='envoy.config.filter.http.health_check.v2.HealthCheck.cluster_min_healthy_percentages', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.config.filter.http.health_check.v2.HealthCheck.headers', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=731,
)

_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY.fields_by_name['value'].message_type = envoy_dot_type_dot_percent__pb2._PERCENT
_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY.containing_type = _HEALTHCHECK
_HEALTHCHECK.fields_by_name['pass_through_mode'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HEALTHCHECK.fields_by_name['cache_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['cluster_min_healthy_percentages'].message_type = _HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY
_HEALTHCHECK.fields_by_name['headers'].message_type = envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2._HEADERMATCHER
DESCRIPTOR.message_types_by_name['HealthCheck'] = _HEALTHCHECK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HealthCheck = _reflection.GeneratedProtocolMessageType('HealthCheck', (_message.Message,), {

  'ClusterMinHealthyPercentagesEntry' : _reflection.GeneratedProtocolMessageType('ClusterMinHealthyPercentagesEntry', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY,
    '__module__' : 'envoy.config.filter.http.health_check.v2.health_check_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.http.health_check.v2.HealthCheck.ClusterMinHealthyPercentagesEntry)
    })
  ,
  'DESCRIPTOR' : _HEALTHCHECK,
  '__module__' : 'envoy.config.filter.http.health_check.v2.health_check_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.health_check.v2.HealthCheck)
  })
_sym_db.RegisterMessage(HealthCheck)
_sym_db.RegisterMessage(HealthCheck.ClusterMinHealthyPercentagesEntry)


DESCRIPTOR._options = None
_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY._options = None
_HEALTHCHECK.fields_by_name['pass_through_mode']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/gzip/v2/gzip.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.filter.http.compressor.v2 import compressor_pb2 as envoy_dot_config_dot_filter_dot_http_dot_compressor_dot_v2_dot_compressor__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/gzip/v2/gzip.proto',
  package='envoy.config.filter.http.gzip.v2',
  syntax='proto3',
  serialized_options=b'\n.io.envoyproxy.envoy.config.filter.http.gzip.v2B\tGzipProtoP\001\362\230\376\217\005\'\022%envoy.extensions.filters.http.gzip.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+envoy/config/filter/http/gzip/v2/gzip.proto\x12 envoy.config.filter.http.gzip.v2\x1a\x37\x65nvoy/config/filter/http/compressor/v2/compressor.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xbb\x05\n\x04Gzip\x12=\n\x0cmemory_level\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\t(\x01\x12\x38\n\x0e\x63ontent_length\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x02\x18\x01\x12\x61\n\x11\x63ompression_level\x18\x03 \x01(\x0e\x32<.envoy.config.filter.http.gzip.v2.Gzip.CompressionLevel.EnumB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x62\n\x14\x63ompression_strategy\x18\x04 \x01(\x0e\x32:.envoy.config.filter.http.gzip.v2.Gzip.CompressionStrategyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x18\n\x0c\x63ontent_type\x18\x06 \x03(\tB\x02\x18\x01\x12\"\n\x16\x64isable_on_etag_header\x18\x07 \x01(\x08\x42\x02\x18\x01\x12)\n\x1dremove_accept_encoding_header\x18\x08 \x01(\x08\x42\x02\x18\x01\x12<\n\x0bwindow_bits\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\x0f(\t\x12\x46\n\ncompressor\x18\n \x01(\x0b\x32\x32.envoy.config.filter.http.compressor.v2.Compressor\x1a<\n\x10\x43ompressionLevel\"(\n\x04\x45num\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x08\n\x04\x42\x45ST\x10\x01\x12\t\n\x05SPEED\x10\x02\"F\n\x13\x43ompressionStrategy\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0c\n\x08\x46ILTERED\x10\x01\x12\x0b\n\x07HUFFMAN\x10\x02\x12\x07\n\x03RLE\x10\x03\x42r\n.io.envoyproxy.envoy.config.filter.http.gzip.v2B\tGzipProtoP\x01\xf2\x98\xfe\x8f\x05\'\x12%envoy.extensions.filters.http.gzip.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_filter_dot_http_dot_compressor_dot_v2_dot_compressor__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_GZIP_COMPRESSIONLEVEL_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='envoy.config.filter.http.gzip.v2.Gzip.CompressionLevel.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BEST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPEED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=846,
  serialized_end=886,
)
_sym_db.RegisterEnumDescriptor(_GZIP_COMPRESSIONLEVEL_ENUM)

_GZIP_COMPRESSIONSTRATEGY = _descriptor.EnumDescriptor(
  name='CompressionStrategy',
  full_name='envoy.config.filter.http.gzip.v2.Gzip.CompressionStrategy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FILTERED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HUFFMAN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RLE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=888,
  serialized_end=958,
)
_sym_db.RegisterEnumDescriptor(_GZIP_COMPRESSIONSTRATEGY)


_GZIP_COMPRESSIONLEVEL = _descriptor.Descriptor(
  name='CompressionLevel',
  full_name='envoy.config.filter.http.gzip.v2.Gzip.CompressionLevel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GZIP_COMPRESSIONLEVEL_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=826,
  serialized_end=886,
)

_GZIP = _descriptor.Descriptor(
  name='Gzip',
  full_name='envoy.config.filter.http.gzip.v2.Gzip',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='memory_level', full_name='envoy.config.filter.http.gzip.v2.Gzip.memory_level', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030\t(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_length', full_name='envoy.config.filter.http.gzip.v2.Gzip.content_length', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression_level', full_name='envoy.config.filter.http.gzip.v2.Gzip.compression_level', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression_strategy', full_name='envoy.config.filter.http.gzip.v2.Gzip.compression_strategy', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='envoy.config.filter.http.gzip.v2.Gzip.content_type', index=4,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_on_etag_header', full_name='envoy.config.filter.http.gzip.v2.Gzip.disable_on_etag_header', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove_accept_encoding_header', full_name='envoy.config.filter.http.gzip.v2.Gzip.remove_accept_encoding_header', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window_bits', full_name='envoy.config.filter.http.gzip.v2.Gzip.window_bits', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030\017(\t', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compressor', full_name='envoy.config.filter.http.gzip.v2.Gzip.compressor', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GZIP_COMPRESSIONLEVEL, ],
  enum_types=[
    _GZIP_COMPRESSIONSTRATEGY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=958,
)

_GZIP_COMPRESSIONLEVEL.containing_type = _GZIP
_GZIP_COMPRESSIONLEVEL_ENUM.containing_type = _GZIP_COMPRESSIONLEVEL
_GZIP.fields_by_name['memory_level'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_GZIP.fields_by_name['content_length'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_GZIP.fields_by_name['compression_level'].enum_type = _GZIP_COMPRESSIONLEVEL_ENUM
_GZIP.fields_by_name['compression_strategy'].enum_type = _GZIP_COMPRESSIONSTRATEGY
_GZIP.fields_by_name['window_bits'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_GZIP.fields_by_name['compressor'].message_type = envoy_dot_config_dot_filter_dot_http_dot_compressor_dot_v2_dot_compressor__pb2._COMPRESSOR
_GZIP_COMPRESSIONSTRATEGY.containing_type = _GZIP
DESCRIPTOR.message_types_by_name['Gzip'] = _GZIP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Gzip = _reflection.GeneratedProtocolMessageType('Gzip', (_message.Message,), {

  'CompressionLevel' : _reflection.GeneratedProtocolMessageType('CompressionLevel', (_message.Message,), {
    'DESCRIPTOR' : _GZIP_COMPRESSIONLEVEL,
    '__module__' : 'envoy.config.filter.http.gzip.v2.gzip_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.http.gzip.v2.Gzip.CompressionLevel)
    })
  ,
  'DESCRIPTOR' : _GZIP,
  '__module__' : 'envoy.config.filter.http.gzip.v2.gzip_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.gzip.v2.Gzip)
  })
_sym_db.RegisterMessage(Gzip)
_sym_db.RegisterMessage(Gzip.CompressionLevel)


DESCRIPTOR._options = None
_GZIP.fields_by_name['memory_level']._options = None
_GZIP.fields_by_name['content_length']._options = None
_GZIP.fields_by_name['compression_level']._options = None
_GZIP.fields_by_name['compression_strategy']._options = None
_GZIP.fields_by_name['content_type']._options = None
_GZIP.fields_by_name['disable_on_etag_header']._options = None
_GZIP.fields_by_name['remove_accept_encoding_header']._options = None
_GZIP.fields_by_name['window_bits']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/discovery/v2/sds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2 import discovery_pb2 as envoy_dot_api_dot_v2_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/discovery/v2/sds.proto',
  package='envoy.service.discovery.v2',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.service.discovery.v2B\010SdsProtoP\001\210\001\001\362\230\376\217\005\031\022\027envoy.service.secret.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$envoy/service/discovery/v2/sds.proto\x12\x1a\x65nvoy.service.discovery.v2\x1a\x1c\x65nvoy/api/v2/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\n\n\x08SdsDummy2\xec\x02\n\x16SecretDiscoveryService\x12_\n\x0c\x44\x65ltaSecrets\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12V\n\rStreamSecrets\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\x00(\x01\x30\x01\x12w\n\x0c\x46\x65tchSecrets\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"&\x82\xd3\xe4\x93\x02\x17\"\x15/v2/discovery:secrets\x82\xd3\xe4\x93\x02\x03:\x01*\x1a \x8a\xa4\x96\xf3\x07\x1a\n\x18\x65nvoy.api.v2.auth.SecretB`\n(io.envoyproxy.envoy.service.discovery.v2B\x08SdsProtoP\x01\x88\x01\x01\xf2\x98\xfe\x8f\x05\x19\x12\x17\x65nvoy.service.secret.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_discovery__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,envoy_dot_annotations_dot_resource__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_SDSDUMMY = _descriptor.Descriptor(
  name='SdsDummy',
  full_name='envoy.service.discovery.v2.SdsDummy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=235,
)

DESCRIPTOR.message_types_by_name['SdsDummy'] = _SDSDUMMY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SdsDummy = _reflection.GeneratedProtocolMessageType('SdsDummy', (_message.Message,), {
  'DESCRIPTOR' : _SDSDUMMY,
  '__module__' : 'envoy.service.discovery.v2.sds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.SdsDummy)
  })
_sym_db.RegisterMessage(SdsDummy)


DESCRIPTOR._options = None

_SECRETDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='SecretDiscoveryService',
  full_name='envoy.service.discovery.v2.SecretDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\212\244\226\363\007\032\n\030envoy.api.v2.auth.Secret',
  create_key=_descriptor._internal_create_key,
  serialized_start=238,
  serialized_end=602,
  methods=[
  _descriptor.MethodDescriptor(
    name='DeltaSecrets',
    full_name='envoy.service.discovery.v2.SecretDiscoveryService.DeltaSecrets',
    index=0,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamSecrets',
    full_name='envoy.service.discovery.v2.SecretDiscoveryService.StreamSecrets',
    index=1,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchSecrets',
    full_name='envoy.service.discovery.v2.SecretDiscoveryService.FetchSecrets',
    index=2,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\"\025/v2/discovery:secrets\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SECRETDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['SecretDiscoveryService'] = _SECRETDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/oauth2/v4alpha/oauth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import http_uri_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_http__uri__pb2
from envoy.config.route.v4alpha import route_components_pb2 as envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2
from envoy.extensions.transport_sockets.tls.v4alpha import secret_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v4alpha_dot_secret__pb2
from envoy.type.matcher.v4alpha import path_pb2 as envoy_dot_type_dot_matcher_dot_v4alpha_dot_path__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/oauth2/v4alpha/oauth.proto',
  package='envoy.extensions.filters.http.oauth2.v4alpha',
  syntax='proto3',
  serialized_options=b'\n:io.envoyproxy.envoy.extensions.filters.http.oauth2.v4alphaB\nOauthProtoP\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n8envoy/extensions/filters/http/oauth2/v4alpha/oauth.proto\x12,envoy.extensions.filters.http.oauth2.v4alpha\x1a(envoy/config/core/v4alpha/http_uri.proto\x1a\x31\x65nvoy/config/route/v4alpha/route_components.proto\x1a;envoy/extensions/transport_sockets/tls/v4alpha/secret.proto\x1a%envoy/type/matcher/v4alpha/path.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xd1\x02\n\x11OAuth2Credentials\x12\x1a\n\tclient_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12_\n\x0ctoken_secret\x18\x02 \x01(\x0b\x32?.envoy.extensions.transport_sockets.tls.v4alpha.SdsSecretConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12`\n\x0bhmac_secret\x18\x03 \x01(\x0b\x32?.envoy.extensions.transport_sockets.tls.v4alpha.SdsSecretConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00:E\x9a\xc5\x88\x1e@\n>envoy.extensions.filters.http.oauth2.v3alpha.OAuth2CredentialsB\x16\n\x0ftoken_formation\x12\x03\xf8\x42\x01\"\xcb\x04\n\x0cOAuth2Config\x12:\n\x0etoken_endpoint\x18\x01 \x01(\x0b\x32\".envoy.config.core.v4alpha.HttpUri\x12\'\n\x16\x61uthorization_endpoint\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12^\n\x0b\x63redentials\x18\x03 \x01(\x0b\x32?.envoy.extensions.filters.http.oauth2.v4alpha.OAuth2CredentialsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1d\n\x0credirect_uri\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12P\n\x15redirect_path_matcher\x18\x05 \x01(\x0b\x32\'.envoy.type.matcher.v4alpha.PathMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12G\n\x0csignout_path\x18\x06 \x01(\x0b\x32\'.envoy.type.matcher.v4alpha.PathMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1c\n\x14\x66orward_bearer_token\x18\x07 \x01(\x08\x12G\n\x14pass_through_matcher\x18\x08 \x03(\x0b\x32).envoy.config.route.v4alpha.HeaderMatcher\x12\x13\n\x0b\x61uth_scopes\x18\t \x03(\t:@\x9a\xc5\x88\x1e;\n9envoy.extensions.filters.http.oauth2.v3alpha.OAuth2Config\"\x90\x01\n\x06OAuth2\x12J\n\x06\x63onfig\x18\x01 \x01(\x0b\x32:.envoy.extensions.filters.http.oauth2.v4alpha.OAuth2Config::\x9a\xc5\x88\x1e\x35\n3envoy.extensions.filters.http.oauth2.v3alpha.OAuth2BZ\n:io.envoyproxy.envoy.extensions.filters.http.oauth2.v4alphaB\nOauthProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_http__uri__pb2.DESCRIPTOR,envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2.DESCRIPTOR,envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v4alpha_dot_secret__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v4alpha_dot_path__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_OAUTH2CREDENTIALS = _descriptor.Descriptor(
  name='OAuth2Credentials',
  full_name='envoy.extensions.filters.http.oauth2.v4alpha.OAuth2Credentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='envoy.extensions.filters.http.oauth2.v4alpha.OAuth2Credentials.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_secret', full_name='envoy.extensions.filters.http.oauth2.v4alpha.OAuth2Credentials.token_secret', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hmac_secret', full_name='envoy.extensions.filters.http.oauth2.v4alpha.OAuth2Credentials.hmac_secret', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036@\n>envoy.extensions.filters.http.oauth2.v3alpha.OAuth2Credentials',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='token_formation', full_name='envoy.extensions.filters.http.oauth2.v4alpha.OAuth2Credentials.token_formation',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=391,
  serialized_end=728,
)


_OAUTH2CONFIG = _descriptor.Descriptor(
  name='OAuth2Config',
  full_name='envoy.extensions.filters.http.oauth2.v4alpha.OAuth2Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token_endpoint', full_name='envoy.extensions.filters.http.oauth2.v4alpha.OAuth2Config.token_endpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authorization_endpoint', full_name='envoy.extensions.filters.http.oauth2.v4alpha.OAuth2Config.authorization_endpoint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='credentials', full_name='envoy.extensions.filters.http.oauth2.v4alpha.OAuth2Config.credentials', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_uri', full_name='envoy.extensions.filters.http.oauth2.v4alpha.OAuth2Config.redirect_uri', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_path_matcher', full_name='envoy.extensions.filters.http.oauth2.v4alpha.OAuth2Config.redirect_path_matcher', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signout_path', full_name='envoy.extensions.filters.http.oauth2.v4alpha.OAuth2Config.signout_path', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forward_bearer_token', full_name='envoy.extensions.filters.http.oauth2.v4alpha.OAuth2Config.forward_bearer_token', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pass_through_matcher', full_name='envoy.extensions.filters.http.oauth2.v4alpha.OAuth2Config.pass_through_matcher', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_scopes', full_name='envoy.extensions.filters.http.oauth2.v4alpha.OAuth2Config.auth_scopes', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036;\n9envoy.extensions.filters.http.oauth2.v3alpha.OAuth2Config',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=731,
  serialized_end=1318,
)


_OAUTH2 = _descriptor.Descriptor(
  name='OAuth2',
  full_name='envoy.extensions.filters.http.oauth2.v4alpha.OAuth2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.extensions.filters.http.oauth2.v4alpha.OAuth2.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0365\n3envoy.extensions.filters.http.oauth2.v3alpha.OAuth2',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1321,
  serialized_end=1465,
)

_OAUTH2CREDENTIALS.fields_by_name['token_secret'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v4alpha_dot_secret__pb2._SDSSECRETCONFIG
_OAUTH2CREDENTIALS.fields_by_name['hmac_secret'].message_type = envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v4alpha_dot_secret__pb2._SDSSECRETCONFIG
_OAUTH2CREDENTIALS.oneofs_by_name['token_formation'].fields.append(
  _OAUTH2CREDENTIALS.fields_by_name['hmac_secret'])
_OAUTH2CREDENTIALS.fields_by_name['hmac_secret'].containing_oneof = _OAUTH2CREDENTIALS.oneofs_by_name['token_formation']
_OAUTH2CONFIG.fields_by_name['token_endpoint'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_http__uri__pb2._HTTPURI
_OAUTH2CONFIG.fields_by_name['credentials'].message_type = _OAUTH2CREDENTIALS
_OAUTH2CONFIG.fields_by_name['redirect_path_matcher'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_path__pb2._PATHMATCHER
_OAUTH2CONFIG.fields_by_name['signout_path'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_path__pb2._PATHMATCHER
_OAUTH2CONFIG.fields_by_name['pass_through_matcher'].message_type = envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2._HEADERMATCHER
_OAUTH2.fields_by_name['config'].message_type = _OAUTH2CONFIG
DESCRIPTOR.message_types_by_name['OAuth2Credentials'] = _OAUTH2CREDENTIALS
DESCRIPTOR.message_types_by_name['OAuth2Config'] = _OAUTH2CONFIG
DESCRIPTOR.message_types_by_name['OAuth2'] = _OAUTH2
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OAuth2Credentials = _reflection.GeneratedProtocolMessageType('OAuth2Credentials', (_message.Message,), {
  'DESCRIPTOR' : _OAUTH2CREDENTIALS,
  '__module__' : 'envoy.extensions.filters.http.oauth2.v4alpha.oauth_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.oauth2.v4alpha.OAuth2Credentials)
  })
_sym_db.RegisterMessage(OAuth2Credentials)

OAuth2Config = _reflection.GeneratedProtocolMessageType('OAuth2Config', (_message.Message,), {
  'DESCRIPTOR' : _OAUTH2CONFIG,
  '__module__' : 'envoy.extensions.filters.http.oauth2.v4alpha.oauth_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.oauth2.v4alpha.OAuth2Config)
  })
_sym_db.RegisterMessage(OAuth2Config)

OAuth2 = _reflection.GeneratedProtocolMessageType('OAuth2', (_message.Message,), {
  'DESCRIPTOR' : _OAUTH2,
  '__module__' : 'envoy.extensions.filters.http.oauth2.v4alpha.oauth_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.oauth2.v4alpha.OAuth2)
  })
_sym_db.RegisterMessage(OAuth2)


DESCRIPTOR._options = None
_OAUTH2CREDENTIALS.oneofs_by_name['token_formation']._options = None
_OAUTH2CREDENTIALS.fields_by_name['client_id']._options = None
_OAUTH2CREDENTIALS.fields_by_name['token_secret']._options = None
_OAUTH2CREDENTIALS.fields_by_name['hmac_secret']._options = None
_OAUTH2CREDENTIALS._options = None
_OAUTH2CONFIG.fields_by_name['authorization_endpoint']._options = None
_OAUTH2CONFIG.fields_by_name['credentials']._options = None
_OAUTH2CONFIG.fields_by_name['redirect_uri']._options = None
_OAUTH2CONFIG.fields_by_name['redirect_path_matcher']._options = None
_OAUTH2CONFIG.fields_by_name['signout_path']._options = None
_OAUTH2CONFIG._options = None
_OAUTH2._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/lua/v3/lua.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/lua/v3/lua.proto',
  package='envoy.extensions.filters.http.lua.v3',
  syntax='proto3',
  serialized_options=b'\n2io.envoyproxy.envoy.extensions.filters.http.lua.v3B\010LuaProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.envoy/extensions/filters/http/lua/v3/lua.proto\x12$envoy.extensions.filters.http.lua.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xf7\x01\n\x03Lua\x12\x1c\n\x0binline_code\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12P\n\x0csource_codes\x18\x02 \x03(\x0b\x32:.envoy.extensions.filters.http.lua.v3.Lua.SourceCodesEntry\x1aT\n\x10SourceCodesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .envoy.config.core.v3.DataSource:\x02\x38\x01:*\x9a\xc5\x88\x1e%\n#envoy.config.filter.http.lua.v2.Lua\"\x8d\x01\n\x0bLuaPerRoute\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12\x17\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x37\n\x0bsource_code\x18\x03 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceH\x00\x42\x0f\n\x08override\x12\x03\xf8\x42\x01\x42H\n2io.envoyproxy.envoy.extensions.filters.http.lua.v3B\x08LuaProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_LUA_SOURCECODESENTRY = _descriptor.Descriptor(
  name='SourceCodesEntry',
  full_name='envoy.extensions.filters.http.lua.v3.Lua.SourceCodesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.extensions.filters.http.lua.v3.Lua.SourceCodesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.extensions.filters.http.lua.v3.Lua.SourceCodesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=332,
  serialized_end=416,
)

_LUA = _descriptor.Descriptor(
  name='Lua',
  full_name='envoy.extensions.filters.http.lua.v3.Lua',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inline_code', full_name='envoy.extensions.filters.http.lua.v3.Lua.inline_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_codes', full_name='envoy.extensions.filters.http.lua.v3.Lua.source_codes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LUA_SOURCECODESENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.config.filter.http.lua.v2.Lua',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=460,
)


_LUAPERROUTE = _descriptor.Descriptor(
  name='LuaPerRoute',
  full_name='envoy.extensions.filters.http.lua.v3.LuaPerRoute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disabled', full_name='envoy.extensions.filters.http.lua.v3.LuaPerRoute.disabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004j\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.http.lua.v3.LuaPerRoute.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_code', full_name='envoy.extensions.filters.http.lua.v3.LuaPerRoute.source_code', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='override', full_name='envoy.extensions.filters.http.lua.v3.LuaPerRoute.override',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=463,
  serialized_end=604,
)

_LUA_SOURCECODESENTRY.fields_by_name['value'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_LUA_SOURCECODESENTRY.containing_type = _LUA
_LUA.fields_by_name['source_codes'].message_type = _LUA_SOURCECODESENTRY
_LUAPERROUTE.fields_by_name['source_code'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_LUAPERROUTE.oneofs_by_name['override'].fields.append(
  _LUAPERROUTE.fields_by_name['disabled'])
_LUAPERROUTE.fields_by_name['disabled'].containing_oneof = _LUAPERROUTE.oneofs_by_name['override']
_LUAPERROUTE.oneofs_by_name['override'].fields.append(
  _LUAPERROUTE.fields_by_name['name'])
_LUAPERROUTE.fields_by_name['name'].containing_oneof = _LUAPERROUTE.oneofs_by_name['override']
_LUAPERROUTE.oneofs_by_name['override'].fields.append(
  _LUAPERROUTE.fields_by_name['source_code'])
_LUAPERROUTE.fields_by_name['source_code'].containing_oneof = _LUAPERROUTE.oneofs_by_name['override']
DESCRIPTOR.message_types_by_name['Lua'] = _LUA
DESCRIPTOR.message_types_by_name['LuaPerRoute'] = _LUAPERROUTE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Lua = _reflection.GeneratedProtocolMessageType('Lua', (_message.Message,), {

  'SourceCodesEntry' : _reflection.GeneratedProtocolMessageType('SourceCodesEntry', (_message.Message,), {
    'DESCRIPTOR' : _LUA_SOURCECODESENTRY,
    '__module__' : 'envoy.extensions.filters.http.lua.v3.lua_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.lua.v3.Lua.SourceCodesEntry)
    })
  ,
  'DESCRIPTOR' : _LUA,
  '__module__' : 'envoy.extensions.filters.http.lua.v3.lua_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.lua.v3.Lua)
  })
_sym_db.RegisterMessage(Lua)
_sym_db.RegisterMessage(Lua.SourceCodesEntry)

LuaPerRoute = _reflection.GeneratedProtocolMessageType('LuaPerRoute', (_message.Message,), {
  'DESCRIPTOR' : _LUAPERROUTE,
  '__module__' : 'envoy.extensions.filters.http.lua.v3.lua_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.lua.v3.LuaPerRoute)
  })
_sym_db.RegisterMessage(LuaPerRoute)


DESCRIPTOR._options = None
_LUA_SOURCECODESENTRY._options = None
_LUA.fields_by_name['inline_code']._options = None
_LUA._options = None
_LUAPERROUTE.oneofs_by_name['override']._options = None
_LUAPERROUTE.fields_by_name['disabled']._options = None
_LUAPERROUTE.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/grpc_credential/v2alpha/file_based_metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/grpc_credential/v2alpha/file_based_metadata.proto',
  package='envoy.config.grpc_credential.v2alpha',
  syntax='proto3',
  serialized_options=b'\n2io.envoyproxy.envoy.config.grpc_credential.v2alphaB\026FileBasedMetadataProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n>envoy/config/grpc_credential/v2alpha/file_based_metadata.proto\x12$envoy.config.grpc_credential.v2alpha\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\"\x80\x01\n\x17\x46ileBasedMetadataConfig\x12:\n\x0bsecret_data\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x12\n\nheader_key\x18\x02 \x01(\t\x12\x15\n\rheader_prefix\x18\x03 \x01(\tBV\n2io.envoyproxy.envoy.config.grpc_credential.v2alphaB\x16\x46ileBasedMetadataProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,udpa_dot_annotations_dot_sensitive__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_FILEBASEDMETADATACONFIG = _descriptor.Descriptor(
  name='FileBasedMetadataConfig',
  full_name='envoy.config.grpc_credential.v2alpha.FileBasedMetadataConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='secret_data', full_name='envoy.config.grpc_credential.v2alpha.FileBasedMetadataConfig.secret_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_key', full_name='envoy.config.grpc_credential.v2alpha.FileBasedMetadataConfig.header_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_prefix', full_name='envoy.config.grpc_credential.v2alpha.FileBasedMetadataConfig.header_prefix', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=200,
  serialized_end=328,
)

_FILEBASEDMETADATACONFIG.fields_by_name['secret_data'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
DESCRIPTOR.message_types_by_name['FileBasedMetadataConfig'] = _FILEBASEDMETADATACONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FileBasedMetadataConfig = _reflection.GeneratedProtocolMessageType('FileBasedMetadataConfig', (_message.Message,), {
  'DESCRIPTOR' : _FILEBASEDMETADATACONFIG,
  '__module__' : 'envoy.config.grpc_credential.v2alpha.file_based_metadata_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.grpc_credential.v2alpha.FileBasedMetadataConfig)
  })
_sym_db.RegisterMessage(FileBasedMetadataConfig)


DESCRIPTOR._options = None
_FILEBASEDMETADATACONFIG.fields_by_name['secret_data']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v3/server_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/admin/v3/server_info.proto',
  package='envoy.admin.v3',
  syntax='proto3',
  serialized_options=b'\n\034io.envoyproxy.envoy.admin.v3B\017ServerInfoProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n envoy/admin/v3/server_info.proto\x12\x0e\x65nvoy.admin.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xb6\x03\n\nServerInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\x12/\n\x05state\x18\x02 \x01(\x0e\x32 .envoy.admin.v3.ServerInfo.State\x12\x37\n\x14uptime_current_epoch\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x34\n\x11uptime_all_epochs\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1b\n\x13hot_restart_version\x18\x05 \x01(\t\x12@\n\x14\x63ommand_line_options\x18\x06 \x01(\x0b\x32\".envoy.admin.v3.CommandLineOptions\x12(\n\x04node\x18\x07 \x01(\x0b\x32\x1a.envoy.config.core.v3.Node\"G\n\x05State\x12\x08\n\x04LIVE\x10\x00\x12\x0c\n\x08\x44RAINING\x10\x01\x12\x14\n\x10PRE_INITIALIZING\x10\x02\x12\x10\n\x0cINITIALIZING\x10\x03:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.admin.v2alpha.ServerInfo\"\x94\n\n\x12\x43ommandLineOptions\x12\x0f\n\x07\x62\x61se_id\x18\x01 \x01(\x04\x12\x1b\n\x13use_dynamic_base_id\x18\x1f \x01(\x08\x12\x14\n\x0c\x62\x61se_id_path\x18  \x01(\t\x12\x13\n\x0b\x63oncurrency\x18\x02 \x01(\r\x12\x13\n\x0b\x63onfig_path\x18\x03 \x01(\t\x12\x13\n\x0b\x63onfig_yaml\x18\x04 \x01(\t\x12#\n\x1b\x61llow_unknown_static_fields\x18\x05 \x01(\x08\x12%\n\x1dreject_unknown_dynamic_fields\x18\x1a \x01(\x08\x12%\n\x1dignore_unknown_dynamic_fields\x18\x1e \x01(\x08\x12\x1a\n\x12\x61\x64min_address_path\x18\x06 \x01(\t\x12N\n\x18local_address_ip_version\x18\x07 \x01(\x0e\x32,.envoy.admin.v3.CommandLineOptions.IpVersion\x12\x11\n\tlog_level\x18\x08 \x01(\t\x12\x1b\n\x13\x63omponent_log_level\x18\t \x01(\t\x12\x12\n\nlog_format\x18\n \x01(\t\x12\x1a\n\x12log_format_escaped\x18\x1b \x01(\x08\x12\x10\n\x08log_path\x18\x0b \x01(\t\x12\x17\n\x0fservice_cluster\x18\r \x01(\t\x12\x14\n\x0cservice_node\x18\x0e \x01(\t\x12\x14\n\x0cservice_zone\x18\x0f \x01(\t\x12\x36\n\x13\x66ile_flush_interval\x18\x10 \x01(\x0b\x32\x19.google.protobuf.Duration\x12-\n\ndrain_time\x18\x11 \x01(\x0b\x32\x19.google.protobuf.Duration\x12H\n\x0e\x64rain_strategy\x18! \x01(\x0e\x32\x30.envoy.admin.v3.CommandLineOptions.DrainStrategy\x12\x37\n\x14parent_shutdown_time\x18\x12 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x35\n\x04mode\x18\x13 \x01(\x0e\x32\'.envoy.admin.v3.CommandLineOptions.Mode\x12\x1b\n\x13\x64isable_hot_restart\x18\x16 \x01(\x08\x12\x1c\n\x14\x65nable_mutex_tracing\x18\x17 \x01(\x08\x12\x15\n\rrestart_epoch\x18\x18 \x01(\r\x12\x16\n\x0e\x63puset_threads\x18\x19 \x01(\x08\x12\x1b\n\x13\x64isabled_extensions\x18\x1c \x03(\t\x12\x19\n\x11\x62ootstrap_version\x18\x1d \x01(\r\x12!\n\x19\x65nable_fine_grain_logging\x18\" \x01(\x08\x12\x13\n\x0bsocket_path\x18# \x01(\t\x12\x13\n\x0bsocket_mode\x18$ \x01(\r\"\x1b\n\tIpVersion\x12\x06\n\x02v4\x10\x00\x12\x06\n\x02v6\x10\x01\"-\n\x04Mode\x12\t\n\x05Serve\x10\x00\x12\x0c\n\x08Validate\x10\x01\x12\x0c\n\x08InitOnly\x10\x02\"+\n\rDrainStrategy\x12\x0b\n\x07Gradual\x10\x00\x12\r\n\tImmediate\x10\x01:-\x9a\xc5\x88\x1e(\n&envoy.admin.v2alpha.CommandLineOptionsJ\x04\x08\x0c\x10\rJ\x04\x08\x14\x10\x15J\x04\x08\x15\x10\x16R\tmax_statsR\x10max_obj_name_lenB9\n\x1cio.envoyproxy.envoy.admin.v3B\x0fServerInfoProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])



_SERVERINFO_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='envoy.admin.v3.ServerInfo.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRAINING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRE_INITIALIZING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INITIALIZING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=512,
  serialized_end=583,
)
_sym_db.RegisterEnumDescriptor(_SERVERINFO_STATE)

_COMMANDLINEOPTIONS_IPVERSION = _descriptor.EnumDescriptor(
  name='IpVersion',
  full_name='envoy.admin.v3.CommandLineOptions.IpVersion',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='v4', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='v6', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1712,
  serialized_end=1739,
)
_sym_db.RegisterEnumDescriptor(_COMMANDLINEOPTIONS_IPVERSION)

_COMMANDLINEOPTIONS_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='envoy.admin.v3.CommandLineOptions.Mode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Serve', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Validate', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='InitOnly', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1741,
  serialized_end=1786,
)
_sym_db.RegisterEnumDescriptor(_COMMANDLINEOPTIONS_MODE)

_COMMANDLINEOPTIONS_DRAINSTRATEGY = _descriptor.EnumDescriptor(
  name='DrainStrategy',
  full_name='envoy.admin.v3.CommandLineOptions.DrainStrategy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Gradual', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Immediate', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1788,
  serialized_end=1831,
)
_sym_db.RegisterEnumDescriptor(_COMMANDLINEOPTIONS_DRAINSTRATEGY)


_SERVERINFO = _descriptor.Descriptor(
  name='ServerInfo',
  full_name='envoy.admin.v3.ServerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='envoy.admin.v3.ServerInfo.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='envoy.admin.v3.ServerInfo.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uptime_current_epoch', full_name='envoy.admin.v3.ServerInfo.uptime_current_epoch', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uptime_all_epochs', full_name='envoy.admin.v3.ServerInfo.uptime_all_epochs', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hot_restart_version', full_name='envoy.admin.v3.ServerInfo.hot_restart_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_line_options', full_name='envoy.admin.v3.ServerInfo.command_line_options', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.admin.v3.ServerInfo.node', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SERVERINFO_STATE,
  ],
  serialized_options=b'\232\305\210\036 \n\036envoy.admin.v2alpha.ServerInfo',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=622,
)


_COMMANDLINEOPTIONS = _descriptor.Descriptor(
  name='CommandLineOptions',
  full_name='envoy.admin.v3.CommandLineOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_id', full_name='envoy.admin.v3.CommandLineOptions.base_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_dynamic_base_id', full_name='envoy.admin.v3.CommandLineOptions.use_dynamic_base_id', index=1,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_id_path', full_name='envoy.admin.v3.CommandLineOptions.base_id_path', index=2,
      number=32, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='concurrency', full_name='envoy.admin.v3.CommandLineOptions.concurrency', index=3,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_path', full_name='envoy.admin.v3.CommandLineOptions.config_path', index=4,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_yaml', full_name='envoy.admin.v3.CommandLineOptions.config_yaml', index=5,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_unknown_static_fields', full_name='envoy.admin.v3.CommandLineOptions.allow_unknown_static_fields', index=6,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reject_unknown_dynamic_fields', full_name='envoy.admin.v3.CommandLineOptions.reject_unknown_dynamic_fields', index=7,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore_unknown_dynamic_fields', full_name='envoy.admin.v3.CommandLineOptions.ignore_unknown_dynamic_fields', index=8,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin_address_path', full_name='envoy.admin.v3.CommandLineOptions.admin_address_path', index=9,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_address_ip_version', full_name='envoy.admin.v3.CommandLineOptions.local_address_ip_version', index=10,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_level', full_name='envoy.admin.v3.CommandLineOptions.log_level', index=11,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='component_log_level', full_name='envoy.admin.v3.CommandLineOptions.component_log_level', index=12,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_format', full_name='envoy.admin.v3.CommandLineOptions.log_format', index=13,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_format_escaped', full_name='envoy.admin.v3.CommandLineOptions.log_format_escaped', index=14,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_path', full_name='envoy.admin.v3.CommandLineOptions.log_path', index=15,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_cluster', full_name='envoy.admin.v3.CommandLineOptions.service_cluster', index=16,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_node', full_name='envoy.admin.v3.CommandLineOptions.service_node', index=17,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_zone', full_name='envoy.admin.v3.CommandLineOptions.service_zone', index=18,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_flush_interval', full_name='envoy.admin.v3.CommandLineOptions.file_flush_interval', index=19,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drain_time', full_name='envoy.admin.v3.CommandLineOptions.drain_time', index=20,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drain_strategy', full_name='envoy.admin.v3.CommandLineOptions.drain_strategy', index=21,
      number=33, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_shutdown_time', full_name='envoy.admin.v3.CommandLineOptions.parent_shutdown_time', index=22,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='envoy.admin.v3.CommandLineOptions.mode', index=23,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_hot_restart', full_name='envoy.admin.v3.CommandLineOptions.disable_hot_restart', index=24,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_mutex_tracing', full_name='envoy.admin.v3.CommandLineOptions.enable_mutex_tracing', index=25,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='restart_epoch', full_name='envoy.admin.v3.CommandLineOptions.restart_epoch', index=26,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpuset_threads', full_name='envoy.admin.v3.CommandLineOptions.cpuset_threads', index=27,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled_extensions', full_name='envoy.admin.v3.CommandLineOptions.disabled_extensions', index=28,
      number=28, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bootstrap_version', full_name='envoy.admin.v3.CommandLineOptions.bootstrap_version', index=29,
      number=29, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_fine_grain_logging', full_name='envoy.admin.v3.CommandLineOptions.enable_fine_grain_logging', index=30,
      number=34, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='socket_path', full_name='envoy.admin.v3.CommandLineOptions.socket_path', index=31,
      number=35, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='socket_mode', full_name='envoy.admin.v3.CommandLineOptions.socket_mode', index=32,
      number=36, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMMANDLINEOPTIONS_IPVERSION,
    _COMMANDLINEOPTIONS_MODE,
    _COMMANDLINEOPTIONS_DRAINSTRATEGY,
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.admin.v2alpha.CommandLineOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=625,
  serialized_end=1925,
)

_SERVERINFO.fields_by_name['state'].enum_type = _SERVERINFO_STATE
_SERVERINFO.fields_by_name['uptime_current_epoch'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SERVERINFO.fields_by_name['uptime_all_epochs'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SERVERINFO.fields_by_name['command_line_options'].message_type = _COMMANDLINEOPTIONS
_SERVERINFO.fields_by_name['node'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._NODE
_SERVERINFO_STATE.containing_type = _SERVERINFO
_COMMANDLINEOPTIONS.fields_by_name['local_address_ip_version'].enum_type = _COMMANDLINEOPTIONS_IPVERSION
_COMMANDLINEOPTIONS.fields_by_name['file_flush_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_COMMANDLINEOPTIONS.fields_by_name['drain_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_COMMANDLINEOPTIONS.fields_by_name['drain_strategy'].enum_type = _COMMANDLINEOPTIONS_DRAINSTRATEGY
_COMMANDLINEOPTIONS.fields_by_name['parent_shutdown_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_COMMANDLINEOPTIONS.fields_by_name['mode'].enum_type = _COMMANDLINEOPTIONS_MODE
_COMMANDLINEOPTIONS_IPVERSION.containing_type = _COMMANDLINEOPTIONS
_COMMANDLINEOPTIONS_MODE.containing_type = _COMMANDLINEOPTIONS
_COMMANDLINEOPTIONS_DRAINSTRATEGY.containing_type = _COMMANDLINEOPTIONS
DESCRIPTOR.message_types_by_name['ServerInfo'] = _SERVERINFO
DESCRIPTOR.message_types_by_name['CommandLineOptions'] = _COMMANDLINEOPTIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ServerInfo = _reflection.GeneratedProtocolMessageType('ServerInfo', (_message.Message,), {
  'DESCRIPTOR' : _SERVERINFO,
  '__module__' : 'envoy.admin.v3.server_info_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v3.ServerInfo)
  })
_sym_db.RegisterMessage(ServerInfo)

CommandLineOptions = _reflection.GeneratedProtocolMessageType('CommandLineOptions', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDLINEOPTIONS,
  '__module__' : 'envoy.admin.v3.server_info_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v3.CommandLineOptions)
  })
_sym_db.RegisterMessage(CommandLineOptions)


DESCRIPTOR._options = None
_SERVERINFO._options = None
_COMMANDLINEOPTIONS._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/annotations/resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/annotations/resource.proto',
  package='envoy.annotations',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n envoy/annotations/resource.proto\x12\x11\x65nvoy.annotations\x1a google/protobuf/descriptor.proto\"\"\n\x12ResourceAnnotation\x12\x0c\n\x04type\x18\x01 \x01(\t:[\n\x08resource\x12\x1f.google.protobuf.ServiceOptions\x18\xc1\xe4\xb2~ \x01(\x0b\x32%.envoy.annotations.ResourceAnnotationb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])


RESOURCE_FIELD_NUMBER = 265073217
resource = _descriptor.FieldDescriptor(
  name='resource', full_name='envoy.annotations.resource', index=0,
  number=265073217, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)


_RESOURCEANNOTATION = _descriptor.Descriptor(
  name='ResourceAnnotation',
  full_name='envoy.annotations.ResourceAnnotation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='envoy.annotations.ResourceAnnotation.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=123,
)

DESCRIPTOR.message_types_by_name['ResourceAnnotation'] = _RESOURCEANNOTATION
DESCRIPTOR.extensions_by_name['resource'] = resource
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ResourceAnnotation = _reflection.GeneratedProtocolMessageType('ResourceAnnotation', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEANNOTATION,
  '__module__' : 'envoy.annotations.resource_pb2'
  # @@protoc_insertion_point(class_scope:envoy.annotations.ResourceAnnotation)
  })
_sym_db.RegisterMessage(ResourceAnnotation)

resource.message_type = _RESOURCEANNOTATION
google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(resource)

# @@protoc_insertion_point(module_scope)
